from ._EventData import EventData


class OrderPictureRetransmit(object):
    def __init__(
        self,          # type: OrderPictureRetransmit
        event_data,    # type: EventData
        payload,       # type: str
    ):
        # type: (...) -> None

        self.event_data = event_data
        self.payload = payload
