from helper import ExtendedEnum

from messagebus import (
    TokenCreator,
    TokenPriority,
)

MSGGRP_PUMP = "B"


class ListenedTokens(ExtendedEnum):
    TK_PUMP_RETRANSMIT_ORDERS = TokenCreator.create_token(
        priority=TokenPriority.low,
        message_group=MSGGRP_PUMP,
        number="1",
    )
