class MissingLogoutInfo(Exception):

    def __init__(
        self,               # type: MissingLogoutInfo
        business_period,    # type: str
    ):
        # type: (...) -> None
        super(MissingLogoutInfo, self).__init__("Missing logout info. Dispatched [MISSING_LOGOUT_INFO] event")

        self.business_period = business_period
